/*

Author: Sjors Hettinga
Date: 14 December 2010
Hardware: ATmega88, with RFM01 en RFM02 modules
			pinout is defined in rf_pin_config.h and in the corresponding schematic
Description: This file declares the public funtions of the packet layer

	Packets are configures as follows:
	--------------------------------------------------------------------
	|| opt8 | len || opt0-7 || crc1 || data0 || ... || data n || crc2 ||
	--------------------------------------------------------------------
	Byte numbers, starting at 1:
	1 )	From the first byte transmitted, the lower 7 bits indicate the number of data bytes send.
		The MSB is bit 8 in the header option.
	2 ) Header option bits 0 - 7
	3 ) The first CRC8, which checks also if the packet lenght is transmitted correctly
	4 .. 3 + len ) Data bytes, that are the actual payload of the packet
	4 + len ) The second CRC8, checking the data

	A complete packet is transmitted by this function
	Also a callback is implemented, that calls a defined function when a packet has arrived
*/

// define the size of the buffers
#define TX_PACKET_BUFFER_SIZE 127
#define RX_PACKET_BUFFER_SIZE 127

// define the struct for the packet
typedef struct {
	unsigned char length;
	unsigned int headerOpt; // 9 bit options in the header
	unsigned char buffer[RX_PACKET_BUFFER_SIZE];
	// pointer to the next packetContents to make a linked list
	// it uses a void* because the packetContents is not declared jet
	void* nextPacketContents; 
} packetContents;

// prototypes of the public functions of the packet layer

// function to init the packet layer
void initPacket(void);

// function to transmit a new packet, max 127 bytes
void sendPacket(unsigned char *buffer, unsigned char len, unsigned int headerOpt);

// function to link the receiver event handler
void setPktReceiver(void (*myPktReceiver)(packetContents*));

// function to check if the transmitter is busy
unsigned char isTransmitterBusy(void);


