/*

Author: Sjors Hettinga
Date: 14 December 2010
Hardware: ATmega88, with RFM01 en RFM02 modules
			pinout is defined in rf_pin_config.h and in the corresponding schematic
Description: This file uses the packet layer build for the RF modules to transmit data to itself. 
			Be aware that relyable transmission is dependant on the responsiveness of the software,
			so when making changes do not block interrupts for a long time, i.e., more then 20 us

			This example outputs its data using the USART at a baudrate of 19.2 kbaud
*/

// AVR lib-C functions
#include <avr/io.h>
#include <util/delay.h>
#include <string.h>

// serial libraries, copied from the examples for the FATFS library
#include "uart.h"
#include "xitoa.h"

// config and packet layer
#include "config.h"
#include "packet.h"

// receive packet function. This function is called by the packet layer when a new packet has arrived
void receivePacket(packetContents* thisPacket){
	for (int i=0; i<thisPacket->length;i++) {
		xputc(thisPacket->buffer[i]);
	}
	xprintf(PSTR("0x%X, %u\n"),thisPacket->headerOpt,thisPacket->length);
}

// main function, this function is called when de controller is booted
int main() {
	// configure the serial port
	xfunc_out = (void (*)(char))uart_put;
	uart_init(); // this function also enable the interrupts!

	// show some output
	xputs(PSTR("Awake\n"));
	
	// wait for the RF-modules to boot
	_delay_ms(200);

	// set the SS line as output to put the SPI in master mode
	DDRB |= 0x04;

	// init the packet layer, this also inits the radio's
	initPacket();
	// assign the callback function when a packet has arrived
	setPktReceiver(receivePacket);

	// declare the test string
	char text[] = "Hi\n";
	char textlen = strlen(text);
	
	// show that the radio's are inited
	// when this point is not reached,
		// the connections to the radio's may be broken
		// or the radio's are not up when they are inited
	xputs(PSTR("Init done\n"));

	// enter the infinite loop
	while(1){
		_delay_ms(2000);	// wait for 2 seconds

		// show that transmission has started
		xputs(PSTR("Start\n"));

		// send a packet
		sendPacket((unsigned char*)text,(unsigned char)textlen,0x1FF);
	}
}
